==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/network/kotlin/inputs/FirewallPolicyRuleApplicationProtocolArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.network.kotlin.inputs

import com.pulumi.azurenative.network.inputs.FirewallPolicyRuleApplicationProtocolArgs.builder
import com.pulumi.azurenative.network.kotlin.enums.FirewallPolicyRuleApplicationProtocolType
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Properties of the application rule protocol.
 * @property port Port number for the protocol, cannot be greater than 64000.
 * @property protocolType Protocol type.
 */
public data class FirewallPolicyRuleApplicationProtocolArgs(
    public val port: Output<Int>? = null,
    public val protocolType: Output<Either<String, FirewallPolicyRuleApplicationProtocolType>>? =
        null,
) :
    ConvertibleToJava<com.pulumi.azurenative.network.inputs.FirewallPolicyRuleApplicationProtocolArgs> {
    override fun toJava():
        com.pulumi.azurenative.network.inputs.FirewallPolicyRuleApplicationProtocolArgs =
        com.pulumi.azurenative.network.inputs.FirewallPolicyRuleApplicationProtocolArgs.builder()
            .port(port?.applyValue({ args0 -> args0 }))
            .protocolType(
                protocolType?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            ).build()
}

/**
 * Builder for [FirewallPolicyRuleApplicationProtocolArgs].
 */
@PulumiTagMarker
public class FirewallPolicyRuleApplicationProtocolArgsBuilder internal constructor() {
    private var port: Output<Int>? = null

    private var protocolType: Output<Either<String, FirewallPolicyRuleApplicationProtocolType>>? =
        null

    /**
     * @param value Port number for the protocol, cannot be greater than 64000.
     */
    @JvmName("kjmwjdiipotjwxho")
    public suspend fun port(`value`: Output<Int>) {
        this.port = value
    }

    /**
     * @param value Protocol type.
     */
    @JvmName("debkystgoqqqunev")
    public suspend
    fun protocolType(`value`: Output<Either<String, FirewallPolicyRuleApplicationProtocolType>>) {
        this.protocolType = value
    }

    /**
     * @param value Port number for the protocol, cannot be greater than 64000.
     */
    @JvmName("qkkkhwikuwqrtfao")
    public suspend fun port(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.port = mapped
    }

    /**
     * @param value Protocol type.
     */
    @JvmName("wvvmdcfwgpltatdt")
    public suspend
    fun protocolType(`value`: Either<String, FirewallPolicyRuleApplicationProtocolType>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.protocolType = mapped
    }

    /**
     * @param value Protocol type.
     */
    @JvmName("ahboicmemmuvgjaa")
    public fun protocolType(`value`: String) {
        val toBeMapped = Either.ofLeft<String, FirewallPolicyRuleApplicationProtocolType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.protocolType = mapped
    }

    /**
     * @param value Protocol type.
     */
    @JvmName("okcfanoncwlpgsyq")
    public fun protocolType(`value`: FirewallPolicyRuleApplicationProtocolType) {
        val toBeMapped = Either.ofRight<String, FirewallPolicyRuleApplicationProtocolType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.protocolType = mapped
    }

    internal fun build(): FirewallPolicyRuleApplicationProtocolArgs =
        FirewallPolicyRuleApplicationProtocolArgs(
            port = port,
            protocolType = protocolType,
        )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/network/kotlin/inputs/FirewallPolicyRuleApplicationProtocolArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.network.kotlin.inputs

import com.pulumi.azurenative.network.inputs.FirewallPolicyRuleApplicationProtocolArgs.builder
import com.pulumi.azurenative.network.kotlin.enums.FirewallPolicyRuleApplicationProtocolType
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Properties of the application rule protocol.
 * @property port Port number for the protocol, cannot be greater than 64000.
 * @property protocolType Protocol type.
 */
public data class FirewallPolicyRuleApplicationProtocolArgs(
    public val port: Output<Int>? = null,
    public val protocolType: Output<Either<String, FirewallPolicyRuleApplicationProtocolType>>? =
        null,
) :
    ConvertibleToJava<com.pulumi.azurenative.network.inputs.FirewallPolicyRuleApplicationProtocolArgs> {
    override fun toJava():
        com.pulumi.azurenative.network.inputs.FirewallPolicyRuleApplicationProtocolArgs =
        com.pulumi.azurenative.network.inputs.FirewallPolicyRuleApplicationProtocolArgs.builder()
            .port(port?.applyValue({ args0 -> args0 }))
            .protocolType(
                protocolType?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            ).build()
}

/**
 * Builder for [FirewallPolicyRuleApplicationProtocolArgs].
 */
@PulumiTagMarker
public class FirewallPolicyRuleApplicationProtocolArgsBuilder internal constructor() {
    private var port: Output<Int>? = null

    private var protocolType: Output<Either<String, FirewallPolicyRuleApplicationProtocolType>>? =
        null

    /**
     * @param value Port number for the protocol, cannot be greater than 64000.
     */
    @JvmName("kdrnpakaujpkmkpw")
    public suspend fun port(`value`: Output<Int>) {
        this.port = value
    }

    /**
     * @param value Protocol type.
     */
    @JvmName("mhedmjtpxbgsbkvg")
    public suspend
    fun protocolType(`value`: Output<Either<String, FirewallPolicyRuleApplicationProtocolType>>) {
        this.protocolType = value
    }

    /**
     * @param value Port number for the protocol, cannot be greater than 64000.
     */
    @JvmName("xcmjjgtfoddfiysh")
    public suspend fun port(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.port = mapped
    }

    /**
     * @param value Protocol type.
     */
    @JvmName("wumkehlrkakbmedi")
    public suspend
    fun protocolType(`value`: Either<String, FirewallPolicyRuleApplicationProtocolType>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.protocolType = mapped
    }

    /**
     * @param value Protocol type.
     */
    @JvmName("dcuppltuppoecium")
    public fun protocolType(`value`: String) {
        val toBeMapped = Either.ofLeft<String, FirewallPolicyRuleApplicationProtocolType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.protocolType = mapped
    }

    /**
     * @param value Protocol type.
     */
    @JvmName("jkdoqpvimdinerxc")
    public fun protocolType(`value`: FirewallPolicyRuleApplicationProtocolType) {
        val toBeMapped = Either.ofRight<String, FirewallPolicyRuleApplicationProtocolType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.protocolType = mapped
    }

    internal fun build(): FirewallPolicyRuleApplicationProtocolArgs =
        FirewallPolicyRuleApplicationProtocolArgs(
            port = port,
            protocolType = protocolType,
        )
}
